import request from '@/utils/request'

// 查询物料列表
export function listMateriel(query) {
  return request({
    url: '/system/materiel/list',
    method: 'get',
    params: query
  })
}
// 查询物料列表
export function treelist() {
  return request({
    url: '/system/materiel/tree/list',
    method: 'get',
  })
}
// 查询物料详细
export function getMateriel(mId) {
  return request({
    url: '/system/materiel/' + mId,
    method: 'get'
  })
}

// 新增物料
export function addMateriel(data) {
  return request({
    url: '/system/materiel',
    method: 'post',
    data: data
  })
}

// 修改物料
export function updateMateriel(data) {
  return request({
    url: '/system/materiel',
    method: 'put',
    data: data
  })
}

// 删除物料
export function delMateriel(mId) {
  return request({
    url: '/system/materiel/' + mId,
    method: 'delete'
  })
}

// 导出物料
export function exportMateriel(query) {
  return request({
    url: '/system/materiel/export',
    method: 'get',
    params: query
  })
}
